@@ -1,4 +1,5 @@
 #include "e_bluez_private.h"
+#include <stdlib.h>
 #include <string.h>
 #include <errno.h>
 
@@ -497,9 +498,9 @@ _e_bluez_element_array_match(E_Bluez_Array *old, E_Bluez_Array *new, const char
    if (old->type != DBUS_TYPE_OBJECT_PATH)
       return;
 
-   if ((!new) || (!new->array) || eina_array_count_get(new->array) == 0)
+   if ((!new) || (!new->array) || eina_array_count(new->array) == 0)
      {
-        if ((!old) || (!old->array) || eina_array_count_get(old->array) == 0)
+        if ((!old) || (!old->array) || eina_array_count(old->array) == 0)
           {
              return;
           }
@@ -517,7 +518,7 @@ _e_bluez_element_array_match(E_Bluez_Array *old, E_Bluez_Array *new, const char
       if (item_old == item_new)
         {
            i_new++;
-           if (i_new >= eina_array_count_get(new->array))
+           if (i_new >= eina_array_count(new->array))
              {
                 i_old++;
                 break;
@@ -532,7 +533,7 @@ _e_bluez_element_array_match(E_Bluez_Array *old, E_Bluez_Array *new, const char
         }
    }
 
-   for(; i_new < eina_array_count_get(new->array); iter_new++, i_new++)
+   for(; i_new < eina_array_count(new->array); iter_new++, i_new++)
      {
         Eina_Bool found = EINA_FALSE;
         item_new = *iter_new;
@@ -568,7 +569,7 @@ _e_bluez_element_array_match(E_Bluez_Array *old, E_Bluez_Array *new, const char
    }
 
 out_remove_remaining:
-   for(; i_old < eina_array_count_get(old->array); iter_old++, i_old++)
+   for(; i_old < eina_array_count(old->array); iter_old++, i_old++)
      {
         E_Bluez_Element *e;
         item_old = *iter_old;
@@ -749,7 +750,7 @@ e_bluez_element_bytes_array_get_stringshared(const E_Bluez_Element *element, con
    if ((!array) || (!(array->array)))
       return NULL;
 
-   *count = eina_array_count_get(array->array);
+   *count = eina_array_count(array->array);
    ret = malloc(*count * sizeof(unsigned char));
    if (!ret)
      {
@@ -805,7 +806,7 @@ e_bluez_element_objects_array_get_stringshared(const E_Bluez_Element *element, c
         return EINA_FALSE;
      }
 
-   *count = eina_array_count_get(array->array);
+   *count = eina_array_count(array->array);
    ret = malloc(*count * sizeof(E_Bluez_Element *));
    if (!ret)
      {
@@ -869,7 +870,7 @@ e_bluez_element_strings_array_get_stringshared(const E_Bluez_Element *element, c
         return EINA_FALSE;
      }
 
-   *count = eina_array_count_get(array->array);
+   *count = eina_array_count(array->array);
    ret = malloc(*count * sizeof(char *));
    if (!ret)
      {
@@ -1495,28 +1496,44 @@ e_bluez_element_property_dict_set_full(E_Bluez_Element *element, const char *pro
         return EINA_FALSE;
      }
 
-   dbus_message_iter_open_container(&itr, DBUS_TYPE_VARIANT, typestr, &variant);
+   if (dbus_message_iter_open_container(&itr, DBUS_TYPE_VARIANT, typestr, &variant))
+     {
+        snprintf(typestr, sizeof(typestr),
+                 (DBUS_DICT_ENTRY_BEGIN_CHAR_AS_STRING
+                     DBUS_TYPE_STRING_AS_STRING
+                     "%c"
+                     DBUS_DICT_ENTRY_END_CHAR_AS_STRING),
+                 type);
+        
+        if (dbus_message_iter_open_container(&variant, DBUS_TYPE_ARRAY, typestr, &dict))
+          {
+             if (dbus_message_iter_open_container(&dict, DBUS_TYPE_DICT_ENTRY, NULL, &entry))
+               {
+                  dbus_message_iter_append_basic(&entry, DBUS_TYPE_STRING, &key);
 
-   snprintf(typestr, sizeof(typestr),
-            (DBUS_DICT_ENTRY_BEGIN_CHAR_AS_STRING
-             DBUS_TYPE_STRING_AS_STRING
-             "%c"
-             DBUS_DICT_ENTRY_END_CHAR_AS_STRING),
-            type);
-
-   dbus_message_iter_open_container(&variant, DBUS_TYPE_ARRAY, typestr, &dict);
-   dbus_message_iter_open_container(&dict, DBUS_TYPE_DICT_ENTRY, NULL, &entry);
-
-   dbus_message_iter_append_basic(&entry, DBUS_TYPE_STRING, &key);
-
-   if ((type == DBUS_TYPE_STRING) || (type == DBUS_TYPE_OBJECT_PATH))
-      dbus_message_iter_append_basic(&entry, type, &value);
+                  if ((type == DBUS_TYPE_STRING) || (type == DBUS_TYPE_OBJECT_PATH))
+                    dbus_message_iter_append_basic(&entry, type, &value);
+                  else
+                    dbus_message_iter_append_basic(&entry, type, value);
+                  
+                  dbus_message_iter_close_container(&dict, &entry);
+               }
+             else
+               {
+                  ERR("dbus_message_iter_open_container() failed");
+               }
+             dbus_message_iter_close_container(&variant, &dict);
+          }
+        else
+          {
+             ERR("dbus_message_iter_open_container() failed");
+          }
+        dbus_message_iter_close_container(&itr, &variant);
+     }
    else
-      dbus_message_iter_append_basic(&entry, type, value);
-
-   dbus_message_iter_close_container(&dict, &entry);
-   dbus_message_iter_close_container(&variant, &dict);
-   dbus_message_iter_close_container(&itr, &variant);
+     {
+        ERR("dbus_message_iter_open_container() failed");
+     }
 
    return e_bluez_element_message_send
              (element, name, NULL, msg, &element->_pending.property_set, cb, data);
@@ -1561,23 +1578,28 @@ e_bluez_element_property_set_full(E_Bluez_Element *element, const char *prop, in
 
    typestr[0] = type;
    typestr[1] = '\0';
-   dbus_message_iter_open_container(&itr, DBUS_TYPE_VARIANT, typestr, &v);
-   if ((type == DBUS_TYPE_STRING) || (type == DBUS_TYPE_OBJECT_PATH))
+   if (dbus_message_iter_open_container(&itr, DBUS_TYPE_VARIANT, typestr, &v))
      {
-        dbus_message_iter_append_basic(&v, type, &value);
-     }
-   else if (type == DBUS_TYPE_BOOLEAN)
-     {
-        unsigned int b = *(char *)value;
-        dbus_message_iter_append_basic(&v, type, &b);
+        if ((type == DBUS_TYPE_STRING) || (type == DBUS_TYPE_OBJECT_PATH))
+          {
+             dbus_message_iter_append_basic(&v, type, &value);
+          }
+        else if (type == DBUS_TYPE_BOOLEAN)
+          {
+             unsigned int b = *(char *)value;
+             dbus_message_iter_append_basic(&v, type, &b);
+          }
+        else
+          {
+             dbus_message_iter_append_basic(&v, type, value);
+          }
+        dbus_message_iter_close_container(&itr, &v);
      }
    else
      {
-        dbus_message_iter_append_basic(&v, type, value);
+        ERR("dbus_message_iter_open_container() failed");
      }
-
-   dbus_message_iter_close_container(&itr, &v);
-
+   
    return e_bluez_element_message_send
              (element, name, NULL, msg, &element->_pending.property_set, cb, data);
 }
